#Example of diversity decomposition using the dataset "phylocom" (R-package picante)

#Librairies
library(picante)
library(ade4)
library(geiger)

#Data preparation
data(phylocom)
spxp <- phylocom$sample
phy <- phylocom$phylo
is.missing<- !(phy$tip.label %in% colnames(spxp))
phy <- drop.tip(phy, phy$tip.label[is.missing])
spxp <- spxp[, phy$tip.label]

#Functions
source("abgFunctions.R")

#Parametrization of the similarity effect for delta = 0.5
phy0.5 <- rescale(phy, model = "delta", 0.5)

#Taxonomic alpha, beta, gamma decomposition
abgDecompQ(spxp, Z = NULL, q = 0)
abgDecompQ(spxp, Z = NULL, q = 1)
abgDecompQ(spxp, Z = NULL, q = 2)
abgDecompQ(spxp, Z = NULL, q = Inf)

#alpha, beta, gamma decomposition using Leinster & Cobbold 2012
dis <- cophenetic(phy0.5)
Z <- 1 - dis/max(dis)

abgDecompQ(spxp, Z, q = 0)
abgDecompQ(spxp, Z, q = 1)
abgDecompQ(spxp, Z, q = 2)
abgDecompQ(spxp, Z, q = Inf)

#alpha beta gamma decomposition using Chao et al. 2012
chao.objs <- chaoObjects(spxp, phy0.5)

abgDecompQ(chao.objs$pi, chao.objs$Z, q = 0)
abgDecompQ(chao.objs$pi, chao.objs$Z, q = 1)
abgDecompQ(chao.objs$pi, chao.objs$Z, q = 2)
abgDecompQ(chao.objs$pi, chao.objs$Z, q = Inf)

# Pairwise beta-diversity (minus 1) between sites using Leinster & Cobbold 2012
beta.dis <- BetaDisQ(spxp, Z, q = 1)
scatter(dudi.pco(as.dist(beta.dis), scannf = F)) #Visualisation of the pairwise beta-diversity pattern

# Pairwise beta-diversity (minus 1) between sites using Chao and al. 2012
beta.dis <- BetaDisQ(chao.objs$pi, chao.objs$Z, q = 1)
scatter(dudi.pco(as.dist(beta.dis), scannf = F))#Visualisation of the pairwise beta-diversity pattern